@@ -18,6 +18,13 @@ from pytype.pytd import pytd_utils
 log = logging.getLogger(__name__)
 
 
+def _get_container_type_key(container):
+  try:
+    return container.get_type_key()
+  except AttributeError:
+    return container
+
+
 class AnnotationClass(_instance_base.SimpleValue, mixin.HasSlots):
   """Base class of annotations that can be parameterized."""
 
@@ -272,12 +279,13 @@ class AnnotationContainer(AnnotationClass):
         for i, name in enumerate(template)
     }
 
-    # For user-defined generic types, check if its type parameter matches
-    # its corresponding concrete type
-    if isinstance(base_cls, _classes.InterpreterClass) and base_cls.template:
+    # Check if the concrete types match the type parameters.
+    if base_cls.template:
+      processed_params = self.ctx.annotation_utils.convert_class_annotations(
+          node, params)
       for formal_param in base_cls.template:
         root_node = self.ctx.root_node
-        param_value = params[formal_param.name]
+        param_value = processed_params[formal_param.name]
         if (isinstance(formal_param, TypeParameter) and
             not formal_param.is_generic() and
             isinstance(param_value, TypeParameter)):
@@ -287,9 +295,17 @@ class AnnotationContainer(AnnotationClass):
           else:
             actual = param_value.instantiate(
                 root_node, container=abstract_utils.DUMMY_CONTAINER)
+        elif param_value.is_concrete and isinstance(param_value.pyval, str):
+          # TODO(b/261769826): Do we need to collect imports here?
+          expr = param_value.pyval
+          annot = LateAnnotation(expr, self.ctx.vm.frames, self.ctx,
+                                 imports=set())
+          base = expr.split("[", 1)[0]
+          self.ctx.vm.late_annotations[base].append(annot)
+          actual = annot.instantiate(root_node)
         else:
           actual = param_value.instantiate(root_node)
-        match_result = self.ctx.matcher(root_node).compute_one_match(
+        match_result = self.ctx.matcher(node).compute_one_match(
             actual, formal_param)
         if not match_result.success:
           if isinstance(param_value, TypeParameter):
@@ -584,7 +600,7 @@ class Union(_base.BaseValue, mixin.NestedAnnotation, mixin.HasSlots):
   def instantiate(self, node, container=None):
     var = self.ctx.program.NewVariable()
     for option in self.options:
-      k = (node, container, option)
+      k = (node, _get_container_type_key(container), option)
       if k in self._instance_cache:
         if self._instance_cache[k] is None:
           self._instance_cache[k] = self.ctx.new_unsolvable(node)
@@ -640,6 +656,7 @@ class LateAnnotation:
     self._imports = imports or {}
     self._type = ctx.convert.unsolvable  # the resolved type of `expr`
     self._unresolved_instances = set()
+    self._resolved_instances = {}
     # _attribute_names needs to be defined last! This contains the names of all
     # of LateAnnotation's attributes, discovered by looking at
     # LateAnnotation.__dict__ and self.__dict__. These names are used in
@@ -712,14 +729,10 @@ class LateAnnotation:
     # Add implicit imports for typing, since we can have late annotations like
     # `set[int]` which get converted to `typing.Set[int]`.
     if "typing" in self._imports:
-      mod = self.ctx.loader.import_name("typing")
+      overlay = self.ctx.vm.import_module("typing", "typing", 0)
       for v in self._imports["typing"]:
         if v not in f_globals.members:
-          if v == "Any":
-            typ = self.ctx.convert.unsolvable
-          else:
-            typ = self.ctx.convert.name_to_value(f"typing.{v}", ast=mod)
-          f_globals.members[v] = typ.to_variable(node)
+          f_globals.members[v] = overlay.get_module(v).load_lazy_attribute(v)
     var, errorlog = abstract_utils.eval_expr(self.ctx, node, f_globals,
                                              f_locals, self.expr)
     if errorlog:
@@ -756,7 +769,10 @@ class LateAnnotation:
   def instantiate(self, node, container=None):
     """Instantiate the pointed-to class, or record a placeholder instance."""
     if self.resolved:
-      return self._type.instantiate(node, container)
+      key = (node, _get_container_type_key(container))
+      if key not in self._resolved_instances:
+        self._resolved_instances[key] = self._type.instantiate(node, container)
+      return self._resolved_instances[key]
     else:
       instance = _instance_base.Instance(self, self.ctx)
       self._unresolved_instances.add(instance)
