@@ -629,8 +629,8 @@ class ErrorLog(ErrorLogBase):
   def _print_noniterable_str_error(self, error):
     """Pretty-print the matcher.NonIterableStrError instance."""
     return (
-        f"Note: {error.left_type.name} does not match iterables by default. "
-        "Learn more: https://github.com/google/pytype/blob/main/docs/faq.md#why-doesnt-str-match-against-string-iterables")
+        f"Note: {error.left_type.name} does not match string iterables by "
+        "default. Learn more: https://github.com/google/pytype/blob/main/docs/faq.md#why-doesnt-str-match-against-string-iterables")
 
   def _print_typed_dict_error(self, error):
     """Pretty-print the matcher.TypedDictError instance."""
@@ -1352,8 +1352,15 @@ class ErrorLog(ErrorLogBase):
     self.error(stack, err_msg, details=details)
 
   @_error_name("invalid-function-definition")
-  def invalid_function_definition(self, stack, msg):
-    self.error(stack, msg)
+  def invalid_function_definition(self, stack, msg, details=None):
+    self.error(stack, msg, details=details)
+
+  @_error_name("invalid-signature-mutation")
+  def invalid_signature_mutation(self, stack, func_name, sig):
+    sig = self._pytd_print(sig)
+    msg = "Invalid self type mutation in pyi method signature"
+    details = f"{func_name}{sig}"
+    self.error(stack, msg, details)
 
   @_error_name("typed-dict-error")
   def typed_dict_error(self, stack, obj, name):
