@@ -3,15 +3,21 @@
 from pytype.overlays import overlay
 from pytype.overlays import special_builtins
 
+_MODULE_NAME = "functools"
+
 
 class FunctoolsOverlay(overlay.Overlay):
   """An overlay for the functools std lib module."""
 
-  MODULE_NAME = "functools"
-
   def __init__(self, ctx):
     member_map = {
-        "cached_property": special_builtins.Property
+        "cached_property": CachedProperty,
     }
-    ast = ctx.loader.import_name(self.MODULE_NAME)
-    super().__init__(ctx, self.MODULE_NAME, member_map, ast)
+    ast = ctx.loader.import_name(_MODULE_NAME)
+    super().__init__(ctx, _MODULE_NAME, member_map, ast)
+
+
+class CachedProperty(special_builtins.PropertyTemplate):
+
+  def __init__(self, ctx):
+    super().__init__(ctx, "cached_property", _MODULE_NAME)
