@@ -556,7 +556,9 @@ class PropertyTemplate(BuiltinClass):
     return ret
 
   def call(self, node, funcv, args):
-    raise NotImplementedError()
+    property_args = self._get_args(args)
+    return node, PropertyInstance(
+        self.ctx, self.name, self, **property_args).to_variable(node)
 
 
 def _is_fn_abstract(func_var):
@@ -654,11 +656,6 @@ class Property(PropertyTemplate):
   def __init__(self, ctx):
     super().__init__(ctx, "property")
 
-  def call(self, node, funcv, args):
-    property_args = self._get_args(args)
-    return node, PropertyInstance(self.ctx, "property", self,
-                                  **property_args).to_variable(node)
-
 
 def _check_method_decorator_arg(fn_var, name, ctx):
   """Check that @classmethod or @staticmethod are applied to a function."""
@@ -692,15 +689,12 @@ class StaticMethodInstance(abstract.Function, mixin.HasSlots):
     return node, self.func
 
 
-class StaticMethod(BuiltinClass):
+class StaticMethodTemplate(BuiltinClass):
   """Static method decorator."""
 
   # Minimal signature, only used for constructing exceptions.
   _SIGNATURE = function.Signature.from_param_names("staticmethod", ("func",))
 
-  def __init__(self, ctx):
-    super().__init__(ctx, "staticmethod")
-
   def call(self, node, funcv, args):
     if len(args.posargs) != 1:
       raise function.WrongArgCount(self._SIGNATURE, args, self.ctx)
@@ -710,6 +704,12 @@ class StaticMethod(BuiltinClass):
     return node, StaticMethodInstance(self.ctx, self, arg).to_variable(node)
 
 
+class StaticMethod(StaticMethodTemplate):
+
+  def __init__(self, ctx):
+    super().__init__(ctx, "staticmethod")
+
+
 class ClassMethodCallable(abstract.BoundFunction):
   """Tag a ClassMethod bound function so we can dispatch on it."""
 
@@ -732,14 +732,11 @@ class ClassMethodInstance(abstract.Function, mixin.HasSlots):
     return node, self.ctx.program.NewVariable(results, [], node)
 
 
-class ClassMethod(BuiltinClass):
-  """Static method decorator."""
+class ClassMethodTemplate(BuiltinClass):
+  """Class method decorator."""
   # Minimal signature, only used for constructing exceptions.
   _SIGNATURE = function.Signature.from_param_names("classmethod", ("func",))
 
-  def __init__(self, ctx):
-    super().__init__(ctx, "classmethod")
-
   def call(self, node, funcv, args):
     if len(args.posargs) != 1:
       raise function.WrongArgCount(self._SIGNATURE, args, self.ctx)
@@ -752,6 +749,12 @@ class ClassMethod(BuiltinClass):
     return node, ClassMethodInstance(self.ctx, self, arg).to_variable(node)
 
 
+class ClassMethod(ClassMethodTemplate):
+
+  def __init__(self, ctx):
+    super().__init__(ctx, "classmethod")
+
+
 class Dict(BuiltinClass):
   """Implementation of builtins.dict."""
 
