@@ -227,7 +227,7 @@ class TestOptimize(parser_test_base.ParserTest):
 
   def test_builtin_superclasses(self):
     src = pytd_src("""
-        def f(x: Union[list, object], y: Union[complex, memoryview]) -> Union[int, bool]: ...
+        def f(x: Union[list, object], y: Union[complex, slice]) -> Union[int, bool]: ...
     """)
     expected = pytd_src("""
         def f(x: builtins.object, y: builtins.object) -> builtins.int: ...
