@@ -7,7 +7,7 @@ and to model path-specific visibility of nested data structures.
 import collections
 import dataclasses
 import logging
-from typing import Set
+from typing import Any, List, Set
 
 from pytype import metrics
 
@@ -109,6 +109,9 @@ class Program:
     self.next_binding_id += 1
     return self.next_binding_id-1
 
+  def calculate_metrics(self):  # pylint: disable=invalid-name
+    return Metrics()  # dummy implementation
+
 
 class CFGNode:
   """A node in the CFG.
@@ -848,3 +851,11 @@ class Solver:
         if self._RecallOrFindSolution(new_state, seen_states):
           return True
     return False
+
+
+# dummy implementation
+class Metrics:
+  binding_count: int
+  cfg_node_metrics: List[Any]
+  variable_metrics: List[Any]
+  solver_metrics: List[Any]
