@@ -353,14 +353,6 @@ def _process_base_class(node, base, ctx):
     base_val = b.data
     if isinstance(b.data, abstract.AnnotationContainer):
       base_val = base_val.base_cls
-    # A class like `class Foo(List["Foo"])` would lead to infinite recursion
-    # when instantiated because we attempt to recursively instantiate its
-    # parameters, so we replace any late annotations with Any.
-    # TODO(rechen): only replace the current class's name. We should keep
-    # other late annotations in order to support things like:
-    #   class Foo(List["Bar"]): ...
-    #   class Bar: ...
-    base_val = ctx.annotation_utils.remove_late_annotations(base_val)
     if isinstance(base_val, abstract.Union):
       # Union[A,B,...] is a valid base class, but we need to flatten it into a
       # single base variable.
